﻿using System;
using System.IO;
using System.Collections.Generic;
using System.Xml.XPath;
using System.Xml;

namespace PdpRtuDownloader.Database
{
	/// <summary>
	/// Gateway to the local XML database.
	/// </summary>
	public class Database
	{
        public const string rootElementName = "pdp_local_db";

        #region Members

		private string xmlFileName;

        #endregion

        #region Properties

		/// <summary>
		/// Gets the file name of the local XML document.
		/// </summary>
		/// <value>The name of the xml file.</value>
		public string XmlFileName
		{
			get { return xmlFileName; }
		}

        #endregion

        #region Constructors

		public Database (string xmlFileName)
		{
			this.xmlFileName = xmlFileName;
		}

        #endregion

        #region Methods

        /// <summary>
        /// Creates an empty local database.
        /// </summary>
        private void CreateEmptyDatabase()
        {
            try
            {
                XmlDocument doc = new XmlDocument();

                XmlNode eRoot = doc.CreateElement(rootElementName);
                doc.AppendChild(eRoot);

                doc.Save(xmlFileName);
            }
            catch (Exception ex)
            {
                throw new DbException("Could not create empty local database.", ex);
            }
        }

        /// <summary>
        /// Loads and returns the database XML document.
        /// </summary>
        /// <returns>The document.</returns>
        public XmlDocument LoadDocument()
        {
            try
            {
                if (!File.Exists(xmlFileName))
                {
                    CreateEmptyDatabase();
                }

                XmlDocument doc = new XmlDocument();
                doc.Load(xmlFileName);

                if (doc[rootElementName] == null)
                {
                    throw new DbException("Invalid or corrupted database. Cannot find the root element.");
                }

                return doc;
            }
            catch (Exception ex)
            {
                throw new DbException("Could not load the database XML document.", ex);
            }
        }

        /// <summary>
        /// Saves the XML database document.
        /// </summary>
        /// <param name="doc">Document.</param>
        public void SaveDocument(XmlDocument doc)
        {
            try
            {
                doc.Save(xmlFileName);
            }
            catch (Exception ex)
            {
                throw new DbException("Could not save the database XML document.", ex);
            }
        }

        #endregion
	}
}

