﻿using System;
using System.Xml;

namespace PdpRtuDownloader.Database.DomainObjects
{
	/// <summary>
	/// RTU (Remote Transfer Unit) station configuration.
	/// </summary>
	public class RtuConfig
	{
		#region Members

		private int stationId;
		private string name;
        private string uri;
		private string login;
		private string password;
		private string description;
		private bool fourPhases;
		private bool locked;
		private bool active;

		#endregion 

		#region Properties

		/// <summary>
		/// Gets or sets a global ID of the station.
		/// </summary>
		/// <value>The station identifier.</value>
		public int StationId
		{
			get { return stationId; }
			set { stationId = value; }
		}

		/// <summary>
		/// Gets or sets a name of the station.
		/// </summary>
		/// <value>The name.</value>
		public string Name
		{
			get { return name; }
			set { name = value; }
		}

        /// <summary>
        /// Gets or sets URI where the measured files are located.
        /// </summary>
        /// <value>The URI.</value>
        public string Uri
        {
            get { return uri; }
            set { uri = value; }
        }

		/// <summary>
		/// Gets or sets a login to access the FTP.
		/// </summary>
		/// <value>The login.</value>
		public string Login
		{
			get { return login; }
			set { login = value; }
		}

		/// <summary>
		/// Gets or sets a password to access the FTP.
		/// </summary>
		/// <value>The password.</value>
		public string Password
		{
			get { return password; }
			set { password = value; }
		}

		/// <summary>
		/// Gets or sets an informative description of the station.
		/// </summary>
		/// <value>The description.</value>
		public string Description
		{
			get { return description; }
			set { description = value; }
		}

		/// <summary>
		/// Gets or sets whether the station supports the fourth phase.
		/// </summary>
		/// <value><c>true</c> if four phases; otherwise, <c>false</c>.</value>
		public bool FourPhases 
		{
			get { return fourPhases; }
			set { fourPhases = value; }
		}

		/// <summary>
		/// Gets or sets whether the station is locked.
		/// </summary>
		/// <value><c>true</c> if locked; otherwise, <c>false</c>.</value>
		public bool Locked
		{
			get { return locked; }
			set { locked = value; }
		}

		/// <summary>
		/// Gets or sets whether the station is active.
		/// </summary>
		/// <value><c>true</c> if active; otherwise, <c>false</c>.</value>
		public bool Active
		{
			get { return active; }
			set { active = value; }
		}

		#endregion
	}
}

