﻿using System;
using System.Xml;

namespace PdpRtuDownloader.LocalDatabase.DomainObjects
{
	/// <summary>
	/// RTU (Remote Transfer Unit) station configuration.
	/// </summary>
	public class RtuConfig: DataObject
	{
		#region Members

		private int stationId;
		private string name;
		private string hostName;
		private int port;
		private string login;
		private string password;
		private string description;
		private bool fourPhases;
		private bool locked;
		private bool active;

		#endregion 

		#region Properties

		/// <summary>
		/// Gets or sets a global ID of the station.
		/// </summary>
		/// <value>The station identifier.</value>
		public int StationId
		{
			get { return stationId; }
			set { stationId = value; }
		}

		/// <summary>
		/// Gets or sets a name of the station.
		/// </summary>
		/// <value>The name.</value>
		public string Name
		{
			get { return name; }
			set { name = value; }
		}

		/// <summary>
		/// Gets or sets a name or IP address of the station FTP host.
		/// </summary>
		/// <value>The name of the host.</value>
		public string HostName
		{
			get { return hostName; }
			set { hostName = value; }
		}

		/// <summary>
		/// Gets or sets a port of the station FTP host.
		/// </summary>
		/// <value>The port.</value>
		public int Port
		{
			get { return port; }
			set { port = value; }
		}

		/// <summary>
		/// Gets or sets a login to access the FTP.
		/// </summary>
		/// <value>The login.</value>
		public string Login
		{
			get { return login; }
			set { login = value; }
		}

		/// <summary>
		/// Gets or sets a password to access the FTP.
		/// </summary>
		/// <value>The password.</value>
		public string Password
		{
			get { return password; }
			set { password = value; }
		}

		/// <summary>
		/// Gets or sets an informative description of the station.
		/// </summary>
		/// <value>The description.</value>
		public string Description
		{
			get { return description; }
			set { description = value; }
		}

		/// <summary>
		/// Gets or sets whether the station supports the fourth phase.
		/// </summary>
		/// <value><c>true</c> if four phases; otherwise, <c>false</c>.</value>
		public bool FourPhases 
		{
			get { return fourPhases; }
			set { fourPhases = value; }
		}

		/// <summary>
		/// Gets or sets whether the station is locked.
		/// </summary>
		/// <value><c>true</c> if locked; otherwise, <c>false</c>.</value>
		public bool Locked
		{
			get { return locked; }
			set { locked = value; }
		}

		/// <summary>
		/// Gets or sets whether the station is active.
		/// </summary>
		/// <value><c>true</c> if active; otherwise, <c>false</c>.</value>
		public bool Active
		{
			get { return active; }
			set { active = value; }
		}

		#endregion

        #region DataObject

        public override XmlNode GetRootElement(XmlDocument doc)
        {
            
        }

        public override bool PkEquals(DataObject other)
        {
            RtuConfig rtuConfig = other as RtuConfig;
            if (rtuConfig == null)
            {
                return false;
            }

            return this.stationId == rtuConfig.stationId;
        }

        /// <summary>
        /// Loads the RtuConfig object from an XML node.
        /// </summary>
        /// <param name="node">Node.</param>
        public override void LoadFromXml(XmlNode node)
        {
            stationId = Convert.ToInt32(node.Attributes["station_id"].Value);
            name = node.Attributes["name"].Value;
            hostName = node.Attributes["host_name"].Value;
            port = Convert.ToInt32(node.Attributes["port"].Value);
            login = node.Attributes["login"].Value;
            password = node.Attributes["password"].Value;
            description = node.Attributes["description"].Value;
            fourPhases = Convert.ToBoolean(node.Attributes["four_phases"].Value);
            locked = Convert.ToBoolean(node.Attributes["locked"].Value);
            active = Convert.ToBoolean(node.Attributes["active"].Value);
        }

        /// <summary>
        /// Saves the RtuConfig object into an XML node.
        /// </summary>
        /// <param name="node">Node.</param>
        public override void SaveToXml(XmlNode node)
        {
            XmlDocument doc = node.OwnerDocument;

            node.Attributes.Append(doc.CreateAttribute("station_id")).Value = Convert.ToString(stationId);
            node.Attributes.Append(doc.CreateAttribute("name")).Value = name;
            node.Attributes.Append(doc.CreateAttribute("host_name")).Value = hostName;
            node.Attributes.Append(doc.CreateAttribute("port")).Value = Convert.ToString(port);
            node.Attributes.Append(doc.CreateAttribute("login")).Value = login;
            node.Attributes.Append(doc.CreateAttribute("password")).Value = password;
            node.Attributes.Append(doc.CreateAttribute("description")).Value = description;
            node.Attributes.Append(doc.CreateAttribute("four_phases")).Value = Convert.ToString(fourPhases);
            node.Attributes.Append(doc.CreateAttribute("locked")).Value = Convert.ToString(locked);
            node.Attributes.Append(doc.CreateAttribute("active")).Value = Convert.ToString(active);
        }

        #endregion
	}
}

